@@ -243,4 +243,13 @@ def token_refresh():
 
     Equivalent to doing `ChatAPI().get_token()`.
     """
+    # from sys import path
+
     ChatAPI().get_token()
+
+
+def funcname(foo):
+    """
+    docstring
+    """
+    print(foo)
